#!/usr/bin/env python

# Import models
from libica.openapi.v2.models import (
    AnalysisInputExternalData,
    AwsTempCredentials,
    CreateData,
    CreateProjectDataCopyBatch,
    CreateProjectDataCopyBatchItem,
    CreateTemporaryCredentials,
    DataIdOrPathList,
    DataUrlWithPath,
    Download,
    Job,
    ProjectData,
    ProjectDataCopyBatch,
    TempCredentials,
    Upload
)

# Import everything
from .functions.project_data_functions import (
    # Project Data functions
    create_data_in_project,
    create_file_in_project,
    create_folder_in_project,
    get_project_data_file_id_from_project_id_and_path,
    get_project_data_folder_id_from_project_id_and_path,
    get_project_data_id_from_project_id_and_path,
    get_project_data_obj_by_id,
    get_project_data_obj_from_project_id_and_path,
    get_project_data_path_by_id,
    list_project_data_non_recursively,
    find_project_data_recursively,
    find_project_data_bulk,
    create_download_url,
    create_download_urls,
    convert_icav2_uri_to_data_obj,
    convert_icav2_uri_to_project_data_obj,
    convert_project_data_obj_to_icav2_uri,
    convert_project_id_and_data_path_to_icav2_uri,
    unpack_icav2_uri,
    coerce_data_id_or_icav2_uri_to_project_data_obj,
    coerce_data_id_icav2_uri_or_path_to_project_data_obj,
    get_aws_credentials_access_for_project_folder,
    is_folder_id_format,
    is_file_id_format,
    is_data_id_format,
    check_folder_exists,
    check_file_exists,
    check_uri_exists,
    presign_folder,
    presign_cwl_directory,
    presign_cwl_directory_with_external_data_mounts,
    read_icav2_file_contents,
    read_icav2_file_contents_to_string,
    get_project_data_upload_url,
    write_icav2_file_contents,
    get_file_by_file_name_from_project_data_list,
    project_data_copy_batch_handler,
    delete_project_data
)

__all__ = [
    # Libica models
    'AnalysisInputExternalData',
    'AwsTempCredentials',
    'CreateData',
    'CreateProjectDataCopyBatch',
    'CreateProjectDataCopyBatchItem',
    'CreateTemporaryCredentials',
    'DataIdOrPathList',
    'DataUrlWithPath',
    'Download',
    'Job',
    'ProjectData',
    'ProjectDataCopyBatch',
    'TempCredentials',
    'Upload',
    # Functions
    'create_data_in_project',
    'create_file_in_project',
    'create_folder_in_project',
    'get_project_data_file_id_from_project_id_and_path',
    'get_project_data_folder_id_from_project_id_and_path',
    'get_project_data_id_from_project_id_and_path',
    'get_project_data_obj_by_id',
    'get_project_data_obj_from_project_id_and_path',
    'get_project_data_path_by_id',
    'list_project_data_non_recursively',
    'find_project_data_recursively',
    'find_project_data_bulk',
    'create_download_url',
    'create_download_urls',
    'convert_icav2_uri_to_data_obj',
    'convert_icav2_uri_to_project_data_obj',
    'convert_project_data_obj_to_icav2_uri',
    'convert_project_id_and_data_path_to_icav2_uri',
    'unpack_icav2_uri',
    'coerce_data_id_or_icav2_uri_to_project_data_obj',
    'coerce_data_id_icav2_uri_or_path_to_project_data_obj',
    'get_aws_credentials_access_for_project_folder',
    'is_folder_id_format',
    'is_file_id_format',
    'is_data_id_format',
    'check_folder_exists',
    'check_file_exists',
    'check_uri_exists',
    'presign_folder',
    'presign_cwl_directory',
    'presign_cwl_directory_with_external_data_mounts',
    'read_icav2_file_contents',
    'read_icav2_file_contents_to_string',
    'get_project_data_upload_url',
    'write_icav2_file_contents',
    'get_file_by_file_name_from_project_data_list',
    'project_data_copy_batch_handler',
    'delete_project_data'
]
